@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,21 +22,21 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.benchmark.php 1.2 03/03/24 00:33:26-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: benchmark.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 error_reporting(E_ALL);
-include_once(APP_JPGRAPH_PATH . "jpgraph.php");
-include_once(APP_JPGRAPH_PATH . "jpgraph_pie.php");
+require_once(APP_JPGRAPH_PATH . "jpgraph.php");
+require_once(APP_JPGRAPH_PATH . "jpgraph_pie.php");
 
 $font = FF_FONT1;
 
-$stats = unserialize(base64_decode($HTTP_POST_VARS["encoded_stats"]));
+$stats = unserialize(base64_decode($_POST["encoded_stats"]));
 $labels = array();
 $data = array();
 foreach ($stats as $point) {
@@ -81,4 +81,3 @@ $graph->legend->Pos(0.06,0.10);
 
 $graph->Add($p1);
 $graph->Stroke();
-?>
\ No newline at end of file
