@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,37 +22,36 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.confirm.php 1.3 03/12/04 17:58:15-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: confirm.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("confirm.tpl.html");
 
-if (@$HTTP_GET_VARS['cat'] == 'newuser') {
-    $res = @User::checkHash($HTTP_GET_VARS["email"], $HTTP_GET_VARS["hash"]);
+if (@$_GET['cat'] == 'newuser') {
+    $res = @User::checkHash($_GET["email"], $_GET["hash"]);
     if ($res == 1) {
-        User::confirmVisitorAccount($HTTP_GET_VARS["email"]);
+        User::confirmVisitorAccount($_GET["email"]);
         // redirect user to login form with pretty message
-        Auth::redirect('index.php?err=8&email=' . $HTTP_GET_VARS["email"]);
+        Auth::redirect('index.php?err=8&email=' . $_GET["email"]);
         exit;
     }
     $tpl->assign("confirm_result", $res);
-} elseif (@$HTTP_GET_VARS['cat'] == 'password') {
-    $res = @User::checkHash($HTTP_GET_VARS["email"], $HTTP_GET_VARS["hash"]);
+} elseif (@$_GET['cat'] == 'password') {
+    $res = @User::checkHash($_GET["email"], $_GET["hash"]);
     if ($res == 1) {
-        User::confirmNewPassword($HTTP_GET_VARS["email"]);
-        $tpl->assign("email", $HTTP_GET_VARS["email"]);
+        User::confirmNewPassword($_GET["email"]);
+        $tpl->assign("email", $_GET["email"]);
     }
     $tpl->assign("confirm_result", $res);
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
