@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,16 +22,16 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.custom_fields.php 1.5 03/11/01 01:08:09-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.custom_field.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: custom_fields.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.custom_field.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("custom_fields_form.tpl.html");
@@ -39,7 +39,7 @@ $tpl->setTemplate("custom_fields_form.tpl.html");
 Auth::checkAuthentication(APP_COOKIE);
 
 $prj_id = Auth::getCurrentProject();
-$issue_id = @$HTTP_POST_VARS["issue_id"] ? $HTTP_POST_VARS["issue_id"] : $HTTP_GET_VARS["issue_id"];
+$issue_id = @$_POST["issue_id"] ? $_POST["issue_id"] : $_GET["issue_id"];
 
 if (!Issue::canAccess($issue_id, Auth::getUserID())) {
     $tpl = new Template_API();
@@ -48,7 +48,7 @@ if (!Issue::canAccess($issue_id, Auth::getUserID())) {
     exit;
 }
 
-if (@$HTTP_POST_VARS["cat"] == "update_values") {
+if (@$_POST["cat"] == "update_values") {
     $res = Custom_Field::updateValues();
     $tpl->assign("update_result", $res);
     $tpl->assign("current_user_prefs", Prefs::get(Auth::getUserID()));
@@ -57,4 +57,3 @@ if (@$HTTP_POST_VARS["cat"] == "update_values") {
 $tpl->assign("custom_fields", Custom_Field::getListByIssue($prj_id, $issue_id));
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
