@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,25 +22,25 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.forgot_password.php 1.8 03/12/12 19:09:43-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.mail.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: forgot_password.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.mail.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("forgot_password.tpl.html");
 
-if (@$HTTP_POST_VARS["cat"] == "reset_password") {
-    if (empty($HTTP_POST_VARS["email"])) {
+if (@$_POST["cat"] == "reset_password") {
+    if (empty($_POST["email"])) {
         $tpl->assign("result", 4);
     }
-    $usr_id = User::getUserIDByEmail($HTTP_POST_VARS["email"]);
+    $usr_id = User::getUserIDByEmail($_POST["email"]);
     if (empty($usr_id)) {
         $tpl->assign("result", 5);
     } else {
@@ -55,4 +55,3 @@ if (@$HTTP_POST_VARS["cat"] == "reset_password") {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
