@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,28 +22,27 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.get_attachment.php 1.5 03/09/30 18:07:03-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.support.php");
-include_once(APP_INC_PATH . "class.mime_helper.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: get_attachment.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.support.php");
+require_once(APP_INC_PATH . "class.mime_helper.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 Auth::checkAuthentication(APP_COOKIE);
 
-if (@$HTTP_GET_VARS['cat'] == 'blocked_email') {
-    $email = Note::getBlockedMessage($HTTP_GET_VARS["note_id"]);
+if (@$_GET['cat'] == 'blocked_email') {
+    $email = Note::getBlockedMessage($_GET["note_id"]);
 } else {
-    $email = Support::getFullEmail($HTTP_GET_VARS["sup_id"]);
+    $email = Support::getFullEmail($_GET["sup_id"]);
 }
-if (!empty($HTTP_GET_VARS['cid'])) {
-    list($mimetype, $data) = Mime_Helper::getAttachment($email, $HTTP_GET_VARS["filename"], $HTTP_GET_VARS["cid"]);
+if (!empty($_GET['cid'])) {
+    list($mimetype, $data) = Mime_Helper::getAttachment($email, $_GET["filename"], $_GET["cid"]);
 } else {
-    list($mimetype, $data) = Mime_Helper::getAttachment($email, $HTTP_GET_VARS["filename"]);
+    list($mimetype, $data) = Mime_Helper::getAttachment($email, $_GET["filename"]);
 }
-Attachment::outputDownload($data, $HTTP_GET_VARS["filename"], strlen($data), $mimetype);
-?>
\ No newline at end of file
+Attachment::outputDownload($data, $_GET["filename"], strlen($data), $mimetype);
