@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,26 +22,26 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.help.php 1.7 03/01/16 01:47:32-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.help.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: help.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.help.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("help/index.tpl.html");
 
 Auth::checkAuthentication(APP_COOKIE, 'index.php?err=5', true);
 
-if ((empty($HTTP_GET_VARS["topic"])) || (!Help::topicExists($HTTP_GET_VARS["topic"]))) {
+if ((empty($_GET["topic"])) || (!Help::topicExists($_GET["topic"]))) {
     $topic = 'main';
 } else {
-    $topic = $HTTP_GET_VARS["topic"];
+    $topic = $_GET["topic"];
 }
 $tpl->assign("topic", $topic);
 $tpl->assign("links", Help::getNavigationLinks($topic));
@@ -50,4 +50,3 @@ if ($topic != "main") {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
