@@ -1,13 +1,11 @@
 <?php
 function smarty_function_get_display_style($params, &$smarty)
 {
-    global $HTTP_COOKIE_VARS;
-
     $print_result = true;
     extract($params);
 
-    if (!empty($HTTP_COOKIE_VARS["visibility_" . $element_name])) {
-        $html_result = 'style="display:' . $HTTP_COOKIE_VARS["visibility_" . $element_name] . ';"';
+    if (!empty($_COOKIE['visibility_' . $element_name])) {
+        $html_result = 'style="display:' . $_COOKIE['visibility_' . $element_name] . ';"';
     }
     // automatically hide the table if there is nothing to be displayed
     if (isset($total)) {
@@ -22,4 +20,3 @@ function smarty_function_get_display_style($params, &$smarty)
         return $html_result;
     }
 }
-?>
\ No newline at end of file
