@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,24 +22,24 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.auth.php 1.37 04/01/16 23:25:25-00:00 jpradomaia $
+// @(#) $Id: class.auth.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.user.php");
 require_once(APP_INC_PATH . "class.customer.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "private_key.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_CONFIG_PATH . "private_key.php");
 
 /**
  * Class to handle authentication issues.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 class Auth
 {
@@ -77,8 +77,7 @@ class Auth
      */
     function getRequestedURL()
     {
-        global $HTTP_SERVER_VARS;
-        return urlencode($HTTP_SERVER_VARS["REQUEST_URI"]);
+        return urlencode($_SERVER["REQUEST_URI"]);
     }
 
 
@@ -95,16 +94,14 @@ class Auth
      */
     function checkAuthentication($cookie_name, $failed_url = NULL, $is_popup = false)
     {
-        global $HTTP_COOKIE_VARS;
-
         if ($failed_url == NULL) {
             $failed_url = APP_RELATIVE_URL . "index.php?err=5";
         }
         $failed_url .= "&url=" . Auth::getRequestedURL();
-        if (!isset($HTTP_COOKIE_VARS[$cookie_name])) {
+        if (!isset($_COOKIE[$cookie_name])) {
             Auth::redirect($failed_url, $is_popup);
         }
-        $cookie = $HTTP_COOKIE_VARS[$cookie_name];
+        $cookie = $_COOKIE[$cookie_name];
         $cookie = unserialize(base64_decode($cookie));
         if (!Auth::isValidCookie($cookie)) {
             Auth::removeCookie($cookie_name);
@@ -118,6 +115,16 @@ class Auth
             Auth::removeCookie($cookie_name);
             Auth::redirect(APP_RELATIVE_URL . "index.php?err=7", $is_popup);
         }
+
+        $usr_id = Auth::getUserID();
+
+        // check the session
+        Session::verify($usr_id);
+
+        if (!defined('SKIP_LANGUAGE_INIT')) {
+            Language::setPreference();
+        }
+
         // check whether the project selection is set or not
         $prj_id = Auth::getCurrentProject();
         if (empty($prj_id)) {
@@ -141,7 +148,7 @@ class Auth
         }
 
         // if the current session is still valid, then renew the expiration
-        Auth::createLoginCookie($cookie_name, $cookie['email'], $cookie['autologin']);
+        Auth::createLoginCookie($cookie_name, $cookie['email']);
         // renew the project cookie as well
         $prj_cookie = Auth::getCookieInfo(APP_PROJECT_COOKIE);
         Auth::setCurrentProject($prj_id, $prj_cookie["remember"]);
@@ -195,9 +202,7 @@ class Auth
      */
     function hasCookieSupport($cookie_name)
     {
-        global $HTTP_COOKIE_VARS;
-
-        if (@!in_array($cookie_name, array_keys($HTTP_COOKIE_VARS))) {
+        if (@!in_array($cookie_name, array_keys($_COOKIE))) {
             return false;
         } else {
             return true;
@@ -214,9 +219,7 @@ class Auth
      */
     function hasValidCookie($cookie_name)
     {
-        global $HTTP_COOKIE_VARS;
-
-        $cookie = @$HTTP_COOKIE_VARS[$cookie_name];
+        $cookie = @$_COOKIE[$cookie_name];
         $cookie = unserialize(base64_decode($cookie));
         if (!Auth::isValidCookie($cookie)) {
             return false;
@@ -236,9 +239,7 @@ class Auth
      */
     function getCookieInfo($cookie_name)
     {
-        global $HTTP_COOKIE_VARS;
-
-        $cookie = @$HTTP_COOKIE_VARS[$cookie_name];
+        $cookie = @$_COOKIE[$cookie_name];
         return unserialize(base64_decode($cookie));
     }
 
@@ -272,20 +273,18 @@ class Auth
      * @access  public
      * @param   string $cookie_name The cookie name to be created
      * @param   string $email The email address to be stored in the cookie
-     * @param   integer $autologin Flag to indicate whether this user should be automatically logged in or not
      * @return  void
      */
-    function createLoginCookie($cookie_name, $email, $autologin = 0)
+    function createLoginCookie($cookie_name, $email)
     {
         $time = time();
         $cookie = array(
             "email"      => $email,
             "login_time" => $time,
             "hash"       => md5($GLOBALS["private_key"] . md5($time) . $email),
-            "autologin"  => $autologin
         );
         $cookie = base64_encode(serialize($cookie));
-        setcookie($cookie_name, $cookie, APP_COOKIE_EXPIRE, APP_COOKIE_URL, APP_COOKIE_DOMAIN);
+        Auth::setCookie($cookie_name, $cookie, APP_COOKIE_EXPIRE);
     }
 
 
@@ -335,7 +334,7 @@ class Auth
      */
     function removeCookie($cookie_name)
     {
-        setcookie($cookie_name, "", time()-36000, APP_COOKIE_URL, APP_COOKIE_DOMAIN);
+        Auth::setCookie($cookie_name, '', time()-36000);
     }
 
 
@@ -386,7 +385,8 @@ class Auth
                  FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "user
                  WHERE
-                    usr_email='" . Misc::escapeString($email) . "'";
+                    usr_email='" . Misc::escapeString($email) . "' AND
+                    usr_id != " . APP_SYSTEM_USER_ID;
         $passwd = $GLOBALS["db_api"]->dbh->getOne($stmt);
         if (PEAR::isError($passwd)) {
             Error_Handler::logError(array($passwd->getMessage(), $passwd->getDebugInfo()), __FILE__, __LINE__);
@@ -413,7 +413,7 @@ class Auth
         if (empty($info)) {
             return '';
         } else {
-            return @User::getUserIDByEmail($info["email"]);
+            return User::getUserIDByEmail($info["email"]);
         }
     }
 
@@ -433,7 +433,7 @@ class Auth
         $usr_id = Auth::getUserID();
         $projects = Project::getAssocList($usr_id);
         if ($usr_id == APP_SYSTEM_USER_ID) {
-            return $cookie['prj_id'];
+            return isset($cookie['prj_id']) ? (int )$cookie['prj_id'] : null;
         }
         if (!in_array($cookie["prj_id"], array_keys($projects))) {
             Auth::redirect(APP_RELATIVE_URL . "select_project.php?err=1");
@@ -490,7 +490,7 @@ class Auth
             "remember" => $remember
         );
         $cookie = base64_encode(serialize($cookie));
-        setcookie(APP_PROJECT_COOKIE, $cookie, APP_PROJECT_COOKIE_EXPIRE, APP_COOKIE_URL, APP_COOKIE_DOMAIN);
+        Auth::setCookie(APP_PROJECT_COOKIE, $cookie, APP_PROJECT_COOKIE_EXPIRE);
         Auth::createFakeCookie(Auth::getUserID(), $project);
     }
 
@@ -503,8 +503,7 @@ class Auth
      */
     function createFakeCookie($usr_id, $project = false)
     {
-        global $HTTP_COOKIE_VARS;
-        include_once(APP_INC_PATH . "private_key.php");
+        require_once(APP_CONFIG_PATH . "private_key.php");
 
         $user_details = User::getDetails($usr_id);
 
@@ -513,16 +512,15 @@ class Auth
             "email" => $user_details['usr_email'],
             "login_time"    =>  $time,
             "hash"       => md5($GLOBALS["private_key"] . md5($time) . $user_details['usr_email']),
-            "autologin" =>  0
         );
-        $HTTP_COOKIE_VARS[APP_COOKIE] = base64_encode(serialize($cookie));
+        $_COOKIE[APP_COOKIE] = base64_encode(serialize($cookie));
         if ($project) {
             $cookie = array(
                 "prj_id"   => $project,
                 "remember" => false
             );
         }
-        $HTTP_COOKIE_VARS[APP_PROJECT_COOKIE] = base64_encode(serialize($cookie));
+        $_COOKIE[APP_PROJECT_COOKIE] = base64_encode(serialize($cookie));
     }
 
 
@@ -542,10 +540,28 @@ class Auth
             return md5($password);
         }
     }
+
+
+    /**
+     * Sets a cookie in the browser
+     *
+     * @param   string  $name The name of the cookie
+     * @param   string  $value The value of the cookie
+     * @param   string  $expiration The expiration data of the cookie
+     */
+    function setCookie($name, $value, $expiration)
+    {
+        if (is_null(APP_COOKIE_DOMAIN)) {
+
+            setcookie($name, $value, $expiration, APP_COOKIE_URL);
+        } else {
+            setcookie($name, $value, $expiration, APP_COOKIE_URL, APP_COOKIE_DOMAIN);
+        }
+    }
+
 }
 
 // benchmarking the included file (aka setup time)
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Auth Class');
 }
-?>
\ No newline at end of file
