@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,13 +22,11 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id$
-//
 
-include_once(APP_INC_PATH . "class.email_account.php");
+require_once(APP_INC_PATH . "class.email_account.php");
 
 class Draft
 {
@@ -40,13 +38,13 @@ class Draft
      */
     function saveRoutedMessage($message)
     {
-        $path = APP_PATH . "misc/routed_drafts/";
         list($usec,) = explode(" ", microtime());
         $filename = date('Y-m-d_H-i-s_') . $usec . '.draft.txt';
-        $fp = @fopen($path . $filename, 'w');
+        $path = APP_ROUTED_MAILS_SAVEDIR . 'routed_drafts/' . $filename;
+        $fp = @fopen($file, 'w');
         @fwrite($fp, $message);
         @fclose($fp);
-        @chmod($path . $filename, 0777);
+        @chmod($file, 0644);
     }
 
 
@@ -115,7 +113,7 @@ class Draft
             }
             Issue::markAsUpdated($issue_id, "draft saved");
             if ($add_history_entry) {
-                History::add($issue_id, $usr_id, History::getTypeID('draft_added'), 'Email message saved as a draft by ' . User::getFullName($usr_id));
+                History::add($issue_id, $usr_id, History::getTypeID('draft_added'), ev_gettext('Email message saved as a draft by %1$s', User::getFullName($usr_id)));
             }
             return 1;
         }
@@ -139,7 +137,7 @@ class Draft
     {
         $issue_id = Misc::escapeInteger($issue_id);
         $emd_id = Misc::escapeInteger($emd_id);
-        $parent_id = Misc::escapeInteger($issue_id);
+        $parent_id = Misc::escapeInteger($parent_id);
         if (empty($parent_id)) {
             $parent_id = 'NULL';
         }
@@ -159,7 +157,7 @@ class Draft
             return -1;
         } else {
             Issue::markAsUpdated($issue_id, "draft saved");
-            History::add($issue_id, $usr_id, History::getTypeID('draft_updated'), 'Email message draft updated by ' . User::getFullName($usr_id));
+            History::add($issue_id, $usr_id, History::getTypeID('draft_updated'), ev_gettext('Email message draft updated by %1$s', User::getFullName($usr_id)));
             Draft::saveEmail($issue_id, $to, $cc, $subject, $message, $parent_id, false, false);
             return 1;
         }
@@ -423,17 +421,15 @@ class Draft
      */
     function send($draft_id)
     {
-        global $HTTP_POST_VARS;
-
         $draft_id = Misc::escapeInteger($draft_id);
         $draft = Draft::getDetails($draft_id);
-        $HTTP_POST_VARS["issue_id"] = $draft["emd_iss_id"];
-        $HTTP_POST_VARS["subject"] = $draft["emd_subject"];
-        $HTTP_POST_VARS["from"] = User::getFromHeader(Auth::getUserID());
-        $HTTP_POST_VARS["to"] = $draft["to"];
-        $HTTP_POST_VARS["cc"] = @join(";", $draft["cc"]);
-        $HTTP_POST_VARS["message"] = $draft["emd_body"];
-        $HTTP_POST_VARS["ema_id"] = Email_Account::getEmailAccount();
+        $_POST["issue_id"] = $draft["emd_iss_id"];
+        $_POST["subject"] = $draft["emd_subject"];
+        $_POST["from"] = User::getFromHeader(Auth::getUserID());
+        $_POST["to"] = $draft["to"];
+        $_POST["cc"] = @join(";", $draft["cc"]);
+        $_POST["message"] = $draft["emd_body"];
+        $_POST["ema_id"] = Email_Account::getEmailAccount();
         $res = Support::sendEmail();
         if ($res == 1) {
            Draft::remove($draft_id);
@@ -473,4 +469,3 @@ class Draft
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Draft Class');
 }
-?>
\ No newline at end of file
