@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,7 +22,7 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
 
@@ -38,17 +38,18 @@
 *
 */
 
-include_once(APP_PEAR_PATH . "Mail/mimeDecode.php");
+require_once(APP_PEAR_PATH . "Mail/mimeDecode.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
 
 /**
- * Class to handle the business logic related to the MIME email 
+ * Class to handle the business logic related to the MIME email
  * processing. The is8bit(), endode() and _encode() functions come from
  * the excellent Horde package at http://www.horde.org. These functions are
  * licensed under the LGPL, and Horde's copyright notice is available
  * above.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 class Mime_Helper
 {
@@ -56,17 +57,27 @@ class Mime_Helper
      * Method used to get charset from raw email.
      *
      * @access  public
-     * @param   string $input The full body of the message
+     * @param   mixed   $input The full body of the message or decoded email.
      * @return  string charset extracted from Content-Type header of email.
      */
     function getCharacterSet($input)
     {
-        $structure = Mime_Helper::decode($input, false, false);
+        if (!is_object($input)) {
+            $input = Mime_Helper::decode($input, false, false);
+        } else {
+            $structure = $input;
+        }
         if (empty($structure)) {
             return false;
         }
 
-        $content_type = @$structure->headers['content-type'];
+        if ($structure->ctype_primary == 'multipart' and $structure->ctype_secondary == 'mixed'
+            and count($structure->parts) >= 1 and $structure->parts[0]->ctype_primary == 'text') {
+            $content_type = $structure->parts[0]->headers['content-type'];
+        } else {
+            $content_type = @$structure->headers['content-type'];
+        }
+
         if (preg_match('/charset\s*=\s*(["\'])?([-\w\d]+)(\1)?;?/i', $content_type, $matches)) {
             return $matches[2];
         }
@@ -88,6 +99,10 @@ class Mime_Helper
     {
         $parts = array();
         Mime_Helper::parse_output($output, $parts);
+        if (empty($parts)) {
+            Error_Handler::logError(array("Mime_Helper::parse_output failed. Corrupted MIME in email?", $output), __FILE__, __LINE__);
+            // we continue as if nothing happened until it's clear it's right check to do.
+        }
         $str = '';
         $is_html = false;
         if (isset($parts["text"])) {
@@ -95,14 +110,11 @@ class Mime_Helper
         } elseif (isset($parts["html"])) {
             $is_html = true;
             $str = join("\n\n", $parts["html"]);
-            
+
             // hack for inotes to prevent content from being displayed all on one line.
             $str = str_replace("</DIV><DIV>", "\n", $str);
             $str = str_replace(array("<br>", "<br />", "<BR>", "<BR />"), "\n", $str);
         }
-        if (@$output->headers['content-transfer-encoding'] == 'quoted-printable') {
-            $str = Mime_Helper::decodeBody($str, 'quoted-printable');
-        }
         // XXX: do we also need to do something here about base64 encoding?
         if ($is_html) {
             $str = strip_tags($str);
@@ -157,7 +169,7 @@ class Mime_Helper
         if (strstr($address, '<')) {
             $address = stripslashes($address);
             $first_part = substr($address, 0, strrpos($address, '<') - 1);
-            $first_part = '"' . $first_part . '"';
+            $first_part = '"' . str_replace('"', '\"',($first_part)) . '"';
             $second_part = substr($address, strrpos($address, '<'));
             $address = $first_part . ' ' . $second_part;
         }
@@ -180,7 +192,7 @@ class Mime_Helper
             $second_part = substr($address, strrpos($address, '<'));
             $address = $first_part;
         }
-        if (preg_match('/^"(.*)"/', $address)) {
+        if (preg_match('/^".*"/', $address)) {
             $address = preg_replace('/^"(.*)"/', '\\1', $address);
         }
         if (!empty($second_part)) {
@@ -203,18 +215,18 @@ class Mime_Helper
         if (Mime_Helper::is8bit($address)) {
             // split into name and address section
             preg_match("/(.*)<(.*)>/", $address, $matches);
-           $address = "=?" . APP_CHARSET . "?Q?" . 
+           $address = "=?" . APP_CHARSET . "?Q?" .
                 str_replace(' ', '_', trim(preg_replace('/([\x80-\xFF]|[\x21-\x2F]|[\xFC])/e', '"=" . strtoupper(dechex(ord(stripslashes("\1"))))', $matches[1]))) . "?= <" . $matches[2] . ">";
            return $address;
         } else {
             return MIME_Helper::quoteSender($address);
         }
     }
-    
-    
+
+
     /**
      * Decodes a quoted printable encoded address and returns the string.
-     * 
+     *
      * @param   string $address The address to decode
      * @return  string The decoded address
      */
@@ -223,26 +235,26 @@ class Mime_Helper
         if (preg_match("/=\?.+\?Q\?(.+)\?= <(.+)>/i", $address, $matches)) {
             return str_replace("_", ' ', quoted_printable_decode($matches[1])) . " <" . $matches[2] . ">";
         } else {
-            return $address;
+            return Mime_Helper::removeQuotes($address);
         }
     }
-    
-    
+
+
     /**
      * Returns if a specified string contains a quoted printable address.
-     * 
+     *
      * @param   string $address The address
      * @return  boolean If the address is quoted printable encoded.
      */
     function isQuotedPrintable($address)
     {
-        if (preg_match("/=\?.+\?Q\?(.+)\?= <(.+)>/i", $address, $matches)) {
+        if (preg_match("/=\?.+\?Q\?.+\?= <.+>/i", $address)) {
             return true;
         } else {
             return false;
         }
     }
-    
+
 
     /**
      * Determine if a string contains 8-bit characters.
@@ -335,14 +347,15 @@ class Mime_Helper
      *
      * @access  public
      * @param   string $hdr_value The string to be encoded
+     * @param   string $charset The charset of the string
      * @return  string The encoded string
      */
-    function encodeValue($hdr_value)
+    function encodeValue($hdr_value, $charset = 'iso-8859-1')
     {
         preg_match_all('/(\w*[\x80-\xFF]+\w*)/', $hdr_value, $matches);
         foreach ($matches[1] as $value) {
             $replacement = preg_replace('/([\x80-\xFF])/e', '"=" . strtoupper(dechex(ord("\1")))', $value);
-            $hdr_value = str_replace($value, '=?iso-8859-1?Q?' . $replacement . '?=', $hdr_value);
+            $hdr_value = str_replace($value, '=?' . $charset . '?Q?' . $replacement . '?=', $hdr_value);
         }
         return $hdr_value;
     }
@@ -438,13 +451,15 @@ class Mime_Helper
      * Method used to check whether a given email message has any attachments.
      *
      * @access  public
-     * @param   string $message The full body of the message
+     * @param   mixed   $message The full body of the message or parsed message structure.
      * @return  boolean
      */
     function hasAttachments($message)
     {
-        $output = Mime_Helper::decode($message, true);
-        $attachments = Mime_Helper::_getAttachmentDetails($output, TRUE);
+        if (!is_object($message)) {
+            $message = Mime_Helper::decode($message, true);
+        }
+        $attachments = Mime_Helper::_getAttachmentDetails($message, TRUE);
         if (count($attachments) > 0) {
             return true;
         } else {
@@ -454,33 +469,36 @@ class Mime_Helper
 
 
     /**
-     * Method used to parse and return the full list of attachments 
+     * Method used to parse and return the full list of attachments
      * associated with a message.
      *
      * @access  public
-     * @param   string $message The full body of the message
+     * @param   mixed   $message The full body of the message or parsed message structure.
      * @return  array The list of attachments, if any
      */
     function getAttachments($message)
     {
-        $output = Mime_Helper::decode($message, true);
-        return Mime_Helper::_getAttachmentDetails($output, TRUE);
+        if (!is_object($message)) {
+            $message = Mime_Helper::decode($message, true);
+        }
+        return Mime_Helper::_getAttachmentDetails($message, TRUE);
     }
 
 
     /**
-     * Method used to parse and return the full list of attachment CIDs 
+     * Method used to parse and return the full list of attachment CIDs
      * associated with a message.
      *
      * @access  public
-     * @param   string $message The full body of the message
+     * @param   mixed   $message The full body of the message or parsed message structure.
      * @return  array The list of attachment CIDs, if any
      */
-    function getAttachmentCIDs(&$message)
+    function getAttachmentCIDs($message)
     {
-        // gotta parse MIME based emails now
-        $output = Mime_Helper::decode($message, true);
-        return Mime_Helper::_getAttachmentDetails($output, TRUE);
+        if (!is_object($message)) {
+            $message = Mime_Helper::decode($message, true);
+        }
+        return Mime_Helper::_getAttachmentDetails($message, true);
     }
 
 
@@ -493,6 +511,7 @@ class Mime_Helper
                 $attachments = array_merge($t, $attachments);
             }
         }
+        // FIXME: content-type is always lowered by PEAR class (CHECKME) and why not $mime_part->content_type?
         $content_type = strtolower(@$mime_part->ctype_primary . '/' . @$mime_part->ctype_secondary);
         if ($content_type == '/') {
             $content_type = '';
@@ -510,16 +529,16 @@ class Mime_Helper
             if (($return_filename != FALSE) && ($mime_part_filename != $return_filename)) {
                 return array();
             }
-            // if requested, return only the details of 
-            // a particular attachment CID. Only really needed 
+            // if requested, return only the details of
+            // a particular attachment CID. Only really needed
             // as hack for inline images
-            if (($return_cid != FALSE) && (@$mime_part->d_parameters['content-id'] != $return_cid)) {
+            if (($return_cid != FALSE) && (@$mime_part->headers['content-id'] != $return_cid)) {
                 return array();
             }
             $found = 1;
         } else {
             if ((!in_array($content_type, Mime_Helper::_getInvalidContentTypes())) &&
-                    (in_array(@strtolower($mime_part->disposition), Mime_Helper::_getValidDispositions())) && 
+                    (in_array(@strtolower($mime_part->disposition), Mime_Helper::_getValidDispositions())) &&
                     (!empty($mime_part_filename))) {
                 // if requested, return only the details of a particular filename
                 if (($return_filename != FALSE) && ($mime_part_filename != $return_filename)) {
@@ -534,7 +553,7 @@ class Mime_Helper
                 'cid'      => @$mime_part->headers['content-id'],
                 'filetype' => $content_type
             );
-            // only include the body of the attachment when 
+            // only include the body of the attachment when
             // requested to save some memory
             if ($return_body == TRUE) {
                 $t['blob'] = &$mime_part->body;
@@ -551,7 +570,7 @@ class Mime_Helper
      * attachment.
      *
      * @access  public
-     * @param   string $message The full content of the message
+     * @param   mixed   $message The full content of the message or parsed message structure.
      * @param   string $filename The filename to look for
      * @param   string $cid The content-id to look for, if any
      * @return  string The full encoded content of the attachment
@@ -559,8 +578,10 @@ class Mime_Helper
     function getAttachment($message, $filename, $cid = FALSE)
     {
         $parts = array();
-        $output = Mime_Helper::decode($message, true);
-        $details = Mime_Helper::_getAttachmentDetails($output, TRUE, $filename, $cid);
+        if (!is_object($message)) {
+            $message = Mime_Helper::decode($message, true);
+        }
+        $details = Mime_Helper::_getAttachmentDetails($message, TRUE, $filename, $cid);
         if (count($details) == 1) {
             return array(
                 $details[0]['filetype'],
@@ -580,15 +601,15 @@ class Mime_Helper
      * @param   boolean $include_bodies Whether to include the bodies in the return value or not
      * @return  mixed The decoded content of the message
      */
-    function decode(&$message, $include_bodies = FALSE, $decode_bodies = TRUE)
+    function decode($message, $include_bodies = FALSE, $decode_bodies = TRUE)
     {
         // need to fix a pretty annoying bug where if the 'boundary' part of a
         // content-type header is split into another line, the PEAR library would
         // not work correctly. this fix will make the boundary part go to the
         // same line as the content-type one
-        if (preg_match("/^(boundary=).*/m", $message)) {
-            $pattern = "/(Content-Type: multipart\/)(.+); ?\r?\n(boundary=)(.*)$/im";
-            $replacement = '$1$2; $3$4';
+        if (preg_match('/^boundary=/m', $message)) {
+            $pattern = "#(Content-Type: multipart/.+); ?\r?\n(boundary=)$#im";
+            $replacement = '$1; $2';
             $message = preg_replace($pattern, $replacement, $message);
         }
 
@@ -610,9 +631,9 @@ class Mime_Helper
      * @access  public
      * @param   object $obj The decoded object structure of the MIME message
      * @param   array $parts The parsed parts of the MIME message
-     * @return  array List of parts that exist in the MIME message
+     * @return  void
      */
-    function parse_output(&$obj, &$parts)
+    function parse_output($obj, &$parts)
     {
         if (!empty($obj->parts)) {
             for ($i = 0; $i < count($obj->parts); $i++) {
@@ -653,41 +674,14 @@ class Mime_Helper
                         @$parts['attachments'][] = $obj->body;
                     } elseif(strtolower(@$obj->disposition) == 'attachment') {
                         @$parts['attachments'][] = $obj->body;
+                    } else {
+                        @$parts['text'][] = $obj->body;
                     }
             }
         }
     }
 
 
-    /**
-     * Method used to decode the body of a MIME encoded message.
-     *
-     * @access  public
-     * @param   string $input The full body of the message
-     * @param   string $encoding The encoding used in the message
-     * @return  string The decoded message body
-     */
-    function decodeBody($input, $encoding = '7bit')
-    {
-        switch ($encoding) {
-            case '7bit':
-                return $input;
-                break;
-
-            case 'quoted-printable':
-                return Mime_Helper::_quotedPrintableDecode($input);
-                break;
-
-            case 'base64':
-                return base64_decode($input);
-                break;
-
-            default:
-                return $input;
-        }
-    }
-
-
     /**
      * Given a quoted-printable string, this
      * function will decode and return it.
@@ -719,13 +713,14 @@ class Mime_Helper
     {
         return array(
             'message/rfc822',
-            'application/pgp-signature'
+            'application/pgp-signature',
+            'application/ms-tnef',
         );
     }
 
 
     /**
-     * Returns the internal list of attachment dispositions that we do not 
+     * Returns the internal list of attachment dispositions that we do not
      * support as valid attachment types.
      *
      * @access private
@@ -738,11 +733,11 @@ class Mime_Helper
             'inline'
         );
     }
-    
-    
+
+
     /**
      * Splits the full email into headers and body
-     * 
+     *
      * @access  public
      * @param   string $message The full email message
      * @param   boolean $unfold If headers should be unfolded
@@ -761,4 +756,3 @@ class Mime_Helper
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Mime_Helper Class');
 }
-?>
\ No newline at end of file
