@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,27 +22,27 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.validation.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.history.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.draft.php");
-include_once(APP_INC_PATH . "class.authorized_replier.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.validation.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.history.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.draft.php");
+require_once(APP_INC_PATH . "class.authorized_replier.php");
 
 /**
  * Class to handle the business logic related to adding, updating or
  * deleting notes from the application.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Note
@@ -138,6 +138,49 @@ class Note
     }
 
 
+    /**
+     * Returns the sequensial note identification number for the given issue.
+     * This is only for display purposes, but has become relied upon by users
+     * as a valid reference number.  It is simply a sequence, starting with the
+     * first note created as #1, and each increasing by 1 there after.
+     */
+    function getNoteSequenceNumber($issue_id, $note_id)
+    {
+        static $issue_note_numbers;
+
+        if (isset($issue_note_numbers[$issue_id][$note_id])) {
+            return $issue_note_numbers[$issue_id][$note_id];
+        }
+
+        $stmt = "SELECT
+                    not_id,
+                    not_iss_id
+                FROM
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "note
+                WHERE
+                    not_iss_id = " . Misc::escapeInteger($issue_id) . "
+                ORDER BY
+                    not_created_date ASC";
+        $res = $GLOBALS["db_api"]->dbh->getAll($stmt,  DB_FETCHMODE_ASSOC);
+        if (PEAR::isError($res)) {
+            Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
+            return "";
+        }
+
+        $sequence_number = 1;
+        foreach ($res as $note_issue_ids) {
+            $issue_note_numbers[$note_issue_ids['not_iss_id']][$note_issue_ids['not_id']] = $sequence_number;
+            $sequence_number++;
+        }
+
+        if (isset($issue_note_numbers[$issue_id][$note_id])) {
+            return $issue_note_numbers[$issue_id][$note_id];
+        }
+
+        return '#';
+    }
+
+
     /**
      * Returns the blocked email message body associated with the given note ID.
      *
@@ -255,13 +298,13 @@ class Note
      */
     function saveRoutedNote($message)
     {
-        $path = APP_PATH . "misc/routed_notes/";
         list($usec,) = explode(" ", microtime());
         $filename = date('Y-m-d_H-i-s_') . $usec . '.note.txt';
-        $fp = @fopen($path . $filename, 'w');
+        $file = APP_ROUTED_MAILS_SAVEDIR . 'routed_notes/' . $filename;
+        $fp = @fopen($file, 'w');
         @fwrite($fp, $message);
         @fclose($fp);
-        @chmod($path . $filename, 0777);
+        @chmod($file, 0644);
     }
 
 
@@ -280,14 +323,12 @@ class Note
      */
     function insert($usr_id, $issue_id, $unknown_user = FALSE, $log = true, $closing = false, $send_notification = true)
     {
-        global $HTTP_POST_VARS;
-
         $issue_id = Misc::escapeInteger($issue_id);
 
-        if (@$HTTP_POST_VARS['add_extra_recipients'] != 'yes') {
+        if (@$_POST['add_extra_recipients'] != 'yes') {
             $note_cc = array();
         } else {
-            $note_cc = $HTTP_POST_VARS['note_cc'];
+            $note_cc = $_POST['note_cc'];
         }
         // add the poster to the list of people to be subscribed to the notification list
         // only if there is no 'unknown user'.
@@ -297,11 +338,11 @@ class Note
                 Notification::subscribeUser($usr_id, $issue_id, $note_cc[$i], Notification::getDefaultActions());
             }
         }
-        if (Validation::isWhitespace($HTTP_POST_VARS["note"])) {
+        if (Validation::isWhitespace($_POST["note"])) {
             return -2;
         }
-        if (empty($HTTP_POST_VARS['message_id'])) {
-            $HTTP_POST_VARS['message_id'] = Mail_API::generateMessageID();
+        if (empty($_POST['message_id'])) {
+            $_POST['message_id'] = Mail_API::generateMessageID();
         }
         $stmt = "INSERT INTO
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "note
@@ -311,11 +352,11 @@ class Note
                     not_created_date,
                     not_note,
                     not_title";
-        if (!@empty($HTTP_POST_VARS['blocked_msg'])) {
+        if (!@empty($_POST['blocked_msg'])) {
             $stmt .= ", not_blocked_message";
         }
         $stmt .= ", not_message_id";
-        if (!@empty($HTTP_POST_VARS['parent_id'])) {
+        if (!@empty($_POST['parent_id'])) {
             $stmt .= ", not_parent_id";
         }
         if ($unknown_user != false) {
@@ -326,14 +367,14 @@ class Note
                     $issue_id,
                     $usr_id,
                     '" . Date_API::getCurrentDateGMT() . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["note"]) . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS["title"]) . "'";
-        if (!@empty($HTTP_POST_VARS['blocked_msg'])) {
-            $stmt .= ", '" . Misc::escapeString($HTTP_POST_VARS['blocked_msg']) . "'";
+                    '" . Misc::escapeString($_POST["note"]) . "',
+                    '" . Misc::escapeString($_POST["title"]) . "'";
+        if (!@empty($_POST['blocked_msg'])) {
+            $stmt .= ", '" . Misc::escapeString($_POST['blocked_msg']) . "'";
         }
-        $stmt .= ", '" . Misc::escapeString($HTTP_POST_VARS['message_id']) . "'";
-        if (!@empty($HTTP_POST_VARS['parent_id'])) {
-            $stmt .= ", " . Misc::escapeInteger($HTTP_POST_VARS['parent_id']) . "";
+        $stmt .= ", '" . Misc::escapeString($_POST['message_id']) . "'";
+        if (!@empty($_POST['parent_id'])) {
+            $stmt .= ", " . Misc::escapeInteger($_POST['parent_id']) . "";
         }
         if ($unknown_user != false) {
             $stmt .= ", '" . Misc::escapeString($unknown_user) . "'";
@@ -354,12 +395,12 @@ class Note
             // send notifications for the issue being updated
             if ($send_notification) {
                 $internal_only = true;
-                if ((@$HTTP_POST_VARS['add_extra_recipients'] != 'yes') && (@count($HTTP_POST_VARS['note_cc']) > 0)) {
-                    Notification::notify($issue_id, 'notes', $new_note_id, $internal_only, $HTTP_POST_VARS['note_cc']);
+                if ((@$_POST['add_extra_recipients'] != 'yes') && (@count($_POST['note_cc']) > 0)) {
+                    Notification::notify($issue_id, 'notes', $new_note_id, $internal_only, $_POST['note_cc']);
                 } else {
                     Notification::notify($issue_id, 'notes', $new_note_id, $internal_only);
                 }
-                Workflow::handleNewNote(Issue::getProjectID($issue_id), $issue_id, $usr_id, $closing);
+                Workflow::handleNewNote(Issue::getProjectID($issue_id), $issue_id, $usr_id, $closing, $new_note_id);
             }
             // need to return the new note id here so it can
             // be re-used to associate internal-only attachments
@@ -524,7 +565,7 @@ class Note
         $body = Mime_Helper::getMessageBody($structure);
         $sender_email = strtolower(Mail_API::getEmailAddress($structure->headers['from']));
         if ($target == 'email') {
-            if (Mime_Helper::hasAttachments($blocked_message)) {
+            if (Mime_Helper::hasAttachments($structure)) {
                 $has_attachments = 1;
             } else {
                 $has_attachments = 0;
@@ -564,7 +605,7 @@ class Note
             }
             $res = Support::insertEmail($t, $structure, $sup_id);
             if ($res != -1) {
-                Support::extractAttachments($issue_id, $blocked_message);
+                Support::extractAttachments($issue_id, $structure);
                 // notifications about new emails are always external
                 $internal_only = false;
                 // special case when emails are bounced back, so we don't want to notify the customer about those
@@ -615,8 +656,11 @@ class Note
         $stmt = "SELECT
                     COUNT(not_id)
                  FROM
-                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "note
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "note,
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue
                  WHERE
+                    not_iss_id = iss_id AND
+                    iss_prj_id = " . Auth::getCurrentProject() . " AND
                     not_created_date BETWEEN '$start' AND '$end' AND
                     not_usr_id = $usr_id AND
                     not_removed = 0";
@@ -830,4 +874,3 @@ class Note
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Note Class');
 }
-?>
\ No newline at end of file
