@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,27 +22,27 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.reminder_action.php 1.2 04/01/19 15:15:25-00:00 jpradomaia $
+// @(#) $Id: class.reminder_action.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.reminder_condition.php");
-include_once(APP_INC_PATH . "class.notification.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.group.php");
-include_once(APP_INC_PATH . "class.mail.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.validation.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.reminder_condition.php");
+require_once(APP_INC_PATH . "class.notification.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.group.php");
+require_once(APP_INC_PATH . "class.mail.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.validation.php");
 
 /**
  * Class to handle the business logic related to the reminder emails
  * that the system sends out.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Reminder_Action
@@ -100,7 +100,7 @@ class Reminder_Action
 
 
     /**
-     * Returns an associative array with the list of reminder action 
+     * Returns an associative array with the list of reminder action
      * IDs and their respective ranking.
      *
      * @access  private
@@ -190,8 +190,6 @@ class Reminder_Action
      */
     function insert()
     {
-        global $HTTP_POST_VARS;
-
         $stmt = "INSERT INTO
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "reminder_action
                  (
@@ -204,14 +202,14 @@ class Reminder_Action
                     rma_alert_group_leader,
                     rma_boilerplate
                  ) VALUES (
-                    " . Misc::escapeInteger($HTTP_POST_VARS['rem_id']) . ",
-                    " . Misc::escapeInteger($HTTP_POST_VARS['type']) . ",
+                    " . Misc::escapeInteger($_POST['rem_id']) . ",
+                    " . Misc::escapeInteger($_POST['type']) . ",
                     '" . Date_API::getCurrentDateGMT() . "',
-                    '" . Misc::escapeString($HTTP_POST_VARS['title']) . "',
-                    '" . Misc::escapeInteger($HTTP_POST_VARS['rank']) . "',
-                    " . Misc::escapeInteger($HTTP_POST_VARS['alert_irc']) . ",
-                    " . Misc::escapeInteger($HTTP_POST_VARS['alert_group_leader']) . ",
-                    '" . Misc::escapeString($HTTP_POST_VARS['boilerplate']) . "'
+                    '" . Misc::escapeString($_POST['title']) . "',
+                    '" . Misc::escapeInteger($_POST['rank']) . "',
+                    " . Misc::escapeInteger($_POST['alert_irc']) . ",
+                    " . Misc::escapeInteger($_POST['alert_group_leader']) . ",
+                    '" . Misc::escapeString($_POST['boilerplate']) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
@@ -220,8 +218,8 @@ class Reminder_Action
         } else {
             $new_rma_id = $GLOBALS["db_api"]->get_last_insert_id();
             // add the user list, if appropriate
-            if (Reminder_Action::isUserList($HTTP_POST_VARS['type'])) {
-                Reminder_Action::associateUserList($new_rma_id, $HTTP_POST_VARS['user_list']);
+            if (Reminder_Action::isUserList($_POST['type'])) {
+                Reminder_Action::associateUserList($new_rma_id, $_POST['user_list']);
             }
             return 1;
         }
@@ -306,30 +304,28 @@ class Reminder_Action
      */
     function update()
     {
-        global $HTTP_POST_VARS;
-
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "reminder_action
                  SET
                     rma_last_updated_date='" . Date_API::getCurrentDateGMT() . "',
-                    rma_rank='" . Misc::escapeInteger($HTTP_POST_VARS['rank']) . "',
-                    rma_title='" . Misc::escapeString($HTTP_POST_VARS['title']) . "',
-                    rma_rmt_id=" . Misc::escapeInteger($HTTP_POST_VARS['type']) . ",
-                    rma_alert_irc=" . Misc::escapeInteger($HTTP_POST_VARS['alert_irc']) . ",
-                    rma_alert_group_leader=" . Misc::escapeInteger($HTTP_POST_VARS['alert_group_leader']) . ",
-                    rma_boilerplate='" . Misc::escapeString($HTTP_POST_VARS['boilerplate']) . "'
+                    rma_rank='" . Misc::escapeInteger($_POST['rank']) . "',
+                    rma_title='" . Misc::escapeString($_POST['title']) . "',
+                    rma_rmt_id=" . Misc::escapeInteger($_POST['type']) . ",
+                    rma_alert_irc=" . Misc::escapeInteger($_POST['alert_irc']) . ",
+                    rma_alert_group_leader=" . Misc::escapeInteger($_POST['alert_group_leader']) . ",
+                    rma_boilerplate='" . Misc::escapeString($_POST['boilerplate']) . "'
                  WHERE
-                    rma_id=" . Misc::escapeInteger($HTTP_POST_VARS['id']);
+                    rma_id=" . Misc::escapeInteger($_POST['id']);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return -1;
         } else {
             // remove any user list associated with this reminder action
-            Reminder_Action::clearActionUserList($HTTP_POST_VARS['id']);
+            Reminder_Action::clearActionUserList($_POST['id']);
             // add the user list back in, if appropriate
-            if (Reminder_Action::isUserList($HTTP_POST_VARS['type'])) {
-                Reminder_Action::associateUserList($HTTP_POST_VARS['id'], $HTTP_POST_VARS['user_list']);
+            if (Reminder_Action::isUserList($_POST['type'])) {
+                Reminder_Action::associateUserList($_POST['id'], $_POST['user_list']);
             }
             return 1;
         }
@@ -446,7 +442,7 @@ class Reminder_Action
 
 
     /**
-     * Method used to get the list of reminder actions to be displayed in the 
+     * Method used to get the list of reminder actions to be displayed in the
      * administration section.
      *
      * @access  public
@@ -597,13 +593,13 @@ class Reminder_Action
         $group_leader_usr_id = 0;
         if ($action['rma_alert_group_leader']) {
             if (Reminder::isDebug()) {
-                echo "  - Processing Group Leader notification\n";
+                echo "  - " . ev_gettext("Processing Group Leader notification") . "\n";
             }
             $group_id = Issue::getGroupID($issue_id);
             // check if there's even a group associated with this issue
             if (empty($group_id)) {
                 if (Reminder::isDebug()) {
-                    echo "  - No group associated with issue $issue_id\n";
+                    echo "  - " . ev_gettext('No group associated with issue %1$s', $issue_id) . "\n";
                 }
             } else {
                 $group_details = Group::getDetails($group_id);
@@ -613,7 +609,7 @@ class Reminder_Action
             }
         }
         if (Reminder::isDebug()) {
-           echo "  - Performing action '$action_type' for issue #$issue_id\n";
+           echo "  - " . ev_gettext('Performing action %1$s for issue # %2$s', $action_type, $issue_id) . "\n";
         }
         switch ($action_type) {
             case 'email_assignee':
@@ -723,7 +719,7 @@ class Reminder_Action
             if (Reminder::isDebug()) {
                 echo "  - No recipients could be found\n";
             }
-            // if not even an irc alert was sent, then save 
+            // if not even an irc alert was sent, then save
             // a notice about this on reminder_sent@, if needed
             if (!$action['rma_alert_irc']) {
                 if (@$setup['email_reminder']['status'] == 'enabled') {
@@ -762,7 +758,7 @@ class Reminder_Action
                 $mail = new Mail_API;
                 $mail->setTextBody($text_message);
                 $setup = $mail->getSMTPSettings();
-                $mail->send($setup["from"], $address, "[#$issue_id] Reminder: " . $action['rma_title'], 0, $issue_id, 'reminder');
+                $mail->send($setup["from"], $address, "[#$issue_id] " . ev_gettext("Reminder") . ": " . $action['rma_title'], 0, $issue_id, 'reminder');
             }
         }
         // - eventum saves the day once again
@@ -802,14 +798,14 @@ class Reminder_Action
                 $mail = new Mail_API;
                 $mail->setTextBody($text_message);
                 $setup = $mail->getSMTPSettings();
-                $mail->send($setup["from"], $address, "[#$issue_id] Reminder Not Triggered: " . $action['rma_title'], 0, $issue_id);
+                $mail->send($setup["from"], $address, "[#$issue_id] " . ev_gettext("Reminder Not Triggered") . ": " . $action['rma_title'], 0, $issue_id);
             }
         }
     }
 
 
     /**
-     * Returns the given list of issues with only the issues that 
+     * Returns the given list of issues with only the issues that
      * were last triggered for the given reminder action ID.
      *
      * @access  public
@@ -837,7 +833,7 @@ class Reminder_Action
         } else {
             $repeat_issues = array();
             foreach ($issues as $issue_id) {
-                // if the issue was already triggered and the last triggered 
+                // if the issue was already triggered and the last triggered
                 // action was the given one, then add it to the list of repeat issues
                 if ((in_array($issue_id, array_keys($triggered_actions))) && ($triggered_actions[$issue_id] == $rma_id)) {
                     $repeat_issues[] = $issue_id;
@@ -849,7 +845,7 @@ class Reminder_Action
 
 
     /**
-     * Records the last triggered reminder action for a given 
+     * Records the last triggered reminder action for a given
      * issue ID.
      *
      * @access  public
@@ -923,4 +919,3 @@ class Reminder_Action
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Reminder_Action Class');
 }
-?>
\ No newline at end of file
