@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,14 +22,14 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id$
+// @(#) $Id: class.round_robin.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . 'class.date.php');
-include_once(APP_INC_PATH . 'class.error_handler.php');
+require_once(APP_INC_PATH . 'class.date.php');
+require_once(APP_INC_PATH . 'class.error_handler.php');
 
 class Round_Robin
 {
@@ -42,7 +42,7 @@ class Round_Robin
      * @param   integer $end The blackout end hour
      * @return  array The blackout dates
      */
-    function getBlackoutDates($user, $start, $end)
+    function getBlackoutDates(&$user, $start, $end)
     {
         $start = substr($start, 0, 2);
         $end = substr($end, 0, 2);
@@ -125,7 +125,7 @@ class Round_Robin
                     break;
                 }
             }
-            // if no user is currently set as the 'next' assignee, 
+            // if no user is currently set as the 'next' assignee,
             // then just get the first one in the list
             if (empty($next_usr_id)) {
                 $next_usr_id = $user_ids[0];
@@ -136,7 +136,7 @@ class Round_Robin
             do {
                 $user = new Date(Date_API::getCurrentUnixTimestampGMT());
                 $user->convertTZById($users[$next_usr_id]['timezone']);
-                list($today, $tomorrow) = Round_Robin::getBlackoutDates(&$user, $blackout_start, $blackout_end);
+                list($today, $tomorrow) = Round_Robin::getBlackoutDates($user, $blackout_start, $blackout_end);
                 $first = new Date($today . ' ' . $blackout_start);
                 $first->setTZById($users[$next_usr_id]['timezone']);
                 $second = new Date($tomorrow . ' ' . $blackout_end);
@@ -248,7 +248,7 @@ class Round_Robin
 
 
     /**
-     * Retrieves the list of users, round robin blackout hours and their 
+     * Retrieves the list of users, round robin blackout hours and their
      * respective preferences with regards to timezones.
      *
      * @access  public
@@ -307,10 +307,8 @@ class Round_Robin
      */
     function insert()
     {
-        global $HTTP_POST_VARS;
-
-        $blackout_start = $HTTP_POST_VARS['blackout_start']['Hour'] . ':' . $HTTP_POST_VARS['blackout_start']['Minute'] . ':00';
-        $blackout_end = $HTTP_POST_VARS['blackout_end']['Hour'] . ':' . $HTTP_POST_VARS['blackout_end']['Minute'] . ':00';
+        $blackout_start = $_POST['blackout_start']['Hour'] . ':' . $_POST['blackout_start']['Minute'] . ':00';
+        $blackout_end = $_POST['blackout_end']['Hour'] . ':' . $_POST['blackout_end']['Minute'] . ':00';
         $stmt = "INSERT INTO
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_round_robin
                  (
@@ -318,7 +316,7 @@ class Round_Robin
                     prr_blackout_start,
                     prr_blackout_end
                  ) VALUES (
-                    " . Misc::escapeInteger($HTTP_POST_VARS["project"]) . ",
+                    " . Misc::escapeInteger($_POST["project"]) . ",
                     '" . Misc::escapeString($blackout_start) . "',
                     '" . Misc::escapeString($blackout_end) . "'
                  )";
@@ -329,7 +327,7 @@ class Round_Robin
         } else {
             $new_id = $GLOBALS["db_api"]->get_last_insert_id();
             // add all of the user associated with this round robin entry
-            foreach ($HTTP_POST_VARS['users'] as $usr_id) {
+            foreach ($_POST['users'] as $usr_id) {
                 Round_Robin::addUserAssociation($new_id, $usr_id);
             }
             return 1;
@@ -467,27 +465,25 @@ class Round_Robin
      */
     function update()
     {
-        global $HTTP_POST_VARS;
-
-        $blackout_start = $HTTP_POST_VARS['blackout_start']['Hour'] . ':' . $HTTP_POST_VARS['blackout_start']['Minute'] . ':00';
-        $blackout_end = $HTTP_POST_VARS['blackout_end']['Hour'] . ':' . $HTTP_POST_VARS['blackout_end']['Minute'] . ':00';
+        $blackout_start = $_POST['blackout_start']['Hour'] . ':' . $_POST['blackout_start']['Minute'] . ':00';
+        $blackout_end = $_POST['blackout_end']['Hour'] . ':' . $_POST['blackout_end']['Minute'] . ':00';
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_round_robin
                  SET
-                    prr_prj_id=" . Misc::escapeInteger($HTTP_POST_VARS["project"]) . ",
+                    prr_prj_id=" . Misc::escapeInteger($_POST["project"]) . ",
                     prr_blackout_start='" . Misc::escapeString($blackout_start) . "',
                     prr_blackout_end='" . Misc::escapeString($blackout_end) . "'
                  WHERE
-                    prr_id=" . Misc::escapeInteger($HTTP_POST_VARS["id"]);
+                    prr_id=" . Misc::escapeInteger($_POST["id"]);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return -1;
         } else {
             // remove all of the associations with users, then add them all again
-            Round_Robin::removeUserAssociations($HTTP_POST_VARS['id']);
-            foreach ($HTTP_POST_VARS['users'] as $usr_id) {
-                Round_Robin::addUserAssociation($HTTP_POST_VARS['id'], $usr_id);
+            Round_Robin::removeUserAssociations($_POST['id']);
+            foreach ($_POST['users'] as $usr_id) {
+                Round_Robin::addUserAssociation($_POST['id'], $usr_id);
             }
             return 1;
         }
@@ -495,7 +491,7 @@ class Round_Robin
 
 
     /**
-     * Method used to remove the user associations for a given round robin 
+     * Method used to remove the user associations for a given round robin
      * entry ID.
      *
      * @access  public
@@ -530,9 +526,7 @@ class Round_Robin
      */
     function remove()
     {
-        global $HTTP_POST_VARS;
-
-        $items = @implode(", ", Misc::escapeInteger($HTTP_POST_VARS["items"]));
+        $items = @implode(", ", Misc::escapeInteger($_POST["items"]));
         $stmt = "DELETE FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "project_round_robin
                  WHERE
@@ -542,7 +536,7 @@ class Round_Robin
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return false;
         } else {
-            Round_Robin::removeUserAssociations($HTTP_POST_VARS['items']);
+            Round_Robin::removeUserAssociations($_POST['items']);
             return true;
         }
     }
@@ -552,4 +546,3 @@ class Round_Robin
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Round_Robin Class');
 }
-?>
\ No newline at end of file
