@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005 MySQL AB                              |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,27 +22,27 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.class.time_tracking.php 1.17 03/12/31 17:29:01-00:00 jpradomaia $
+// @(#) $Id: class.time_tracking.php 3307 2007-04-11 23:50:22Z balsdorf $
 //
 
-include_once(APP_INC_PATH . "class.error_handler.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.validation.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.user.php");
-include_once(APP_INC_PATH . "class.history.php");
+require_once(APP_INC_PATH . "class.error_handler.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.validation.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.user.php");
+require_once(APP_INC_PATH . "class.history.php");
 
 /**
  * Class to handle the business logic related to the administration
  * of time tracking categories in the system.
  *
  * @version 1.0
- * @author Joo Prado Maia <jpm@mysql.com>
+ * @author João Prado Maia <jpm@mysql.com>
  */
 
 class Time_Tracking
@@ -105,9 +105,7 @@ class Time_Tracking
      */
     function remove()
     {
-        global $HTTP_POST_VARS;
-
-        $items = @implode(", ", Misc::escapeInteger($HTTP_POST_VARS["items"]));
+        $items = @implode(", ", Misc::escapeInteger($_POST["items"]));
         $stmt = "DELETE FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "time_tracking_category
                  WHERE
@@ -130,17 +128,15 @@ class Time_Tracking
      */
     function update()
     {
-        global $HTTP_POST_VARS;
-
-        if (Validation::isWhitespace($HTTP_POST_VARS["title"])) {
+        if (Validation::isWhitespace($_POST["title"])) {
             return -2;
         }
         $stmt = "UPDATE
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "time_tracking_category
                  SET
-                    ttc_title='" . Misc::escapeString($HTTP_POST_VARS["title"]) . "'
+                    ttc_title='" . Misc::escapeString($_POST["title"]) . "'
                  WHERE
-                    ttc_id=" . Misc::escapeInteger($HTTP_POST_VARS["id"]);
+                    ttc_id=" . Misc::escapeInteger($_POST["id"]);
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
@@ -159,9 +155,7 @@ class Time_Tracking
      */
     function insert()
     {
-        global $HTTP_POST_VARS;
-
-        if (Validation::isWhitespace($HTTP_POST_VARS["title"])) {
+        if (Validation::isWhitespace($_POST["title"])) {
             return -2;
         }
         $stmt = "INSERT INTO
@@ -170,7 +164,7 @@ class Time_Tracking
                     ttc_title,
                     ttc_created_date
                  ) VALUES (
-                    '" . Misc::escapeString($HTTP_POST_VARS["title"]) . "',
+                    '" . Misc::escapeString($_POST["title"]) . "',
                     '" . Date_API::getCurrentDateGMT() . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
@@ -408,7 +402,7 @@ class Time_Tracking
         } else {
             Issue::markAsUpdated($details['issue_id']);
             // need to save a history entry for this
-            History::add($details['issue_id'], $usr_id, History::getTypeID('time_removed'), 'Time tracking entry removed by ' . User::getFullName($usr_id));
+            History::add($details['issue_id'], $usr_id, History::getTypeID('time_removed'), ev_gettext('Time tracking entry removed by %1$s', User::getFullName($usr_id)));
             return 1;
         }
     }
@@ -422,14 +416,12 @@ class Time_Tracking
      */
     function insertEntry()
     {
-        global $HTTP_POST_VARS;
-
-        if (!empty($HTTP_POST_VARS["date"])) {
+        if (!empty($_POST["date"])) {
             // format the date from the form
             $created_date = sprintf('%04d-%02d-%02d %02d:%02d:%02d',
-                $HTTP_POST_VARS["date"]["Year"], $HTTP_POST_VARS["date"]["Month"],
-                $HTTP_POST_VARS["date"]["Day"], $HTTP_POST_VARS["date"]["Hour"],
-                $HTTP_POST_VARS["date"]["Minute"], 0);
+                $_POST["date"]["Year"], $_POST["date"]["Month"],
+                $_POST["date"]["Day"], $_POST["date"]["Hour"],
+                $_POST["date"]["Minute"], 0);
             // convert the date to GMT timezone
             $created_date = Date_API::getDateGMT($created_date);
         } else {
@@ -446,21 +438,21 @@ class Time_Tracking
                     ttr_time_spent,
                     ttr_summary
                  ) VALUES (
-                    " . $HTTP_POST_VARS["category"] . ",
-                    " . $HTTP_POST_VARS["issue_id"] . ",
+                    " . $_POST["category"] . ",
+                    " . $_POST["issue_id"] . ",
                     $usr_id,
                     '$created_date',
-                    " . $HTTP_POST_VARS["time_spent"] . ",
-                    '" . Misc::escapeString($HTTP_POST_VARS["summary"]) . "'
+                    " . Misc::escapeInteger($_POST["time_spent"]) . ",
+                    '" . Misc::escapeString($_POST["summary"]) . "'
                  )";
         $res = $GLOBALS["db_api"]->dbh->query($stmt);
         if (PEAR::isError($res)) {
             Error_Handler::logError(array($res->getMessage(), $res->getDebugInfo()), __FILE__, __LINE__);
             return -1;
         } else {
-            Issue::markAsUpdated($HTTP_POST_VARS["issue_id"], 'time added');
+            Issue::markAsUpdated($_POST["issue_id"], 'time added');
             // need to save a history entry for this
-            History::add($HTTP_POST_VARS["issue_id"], $usr_id, History::getTypeID('time_added'), 'Time tracking entry submitted by ' . User::getFullName($usr_id));
+            History::add($_POST["issue_id"], $usr_id, History::getTypeID('time_added'), ev_gettext('Time tracking entry submitted by %1$s', User::getFullName($usr_id)));
             return 1;
         }
     }
@@ -503,7 +495,7 @@ class Time_Tracking
         } else {
             Issue::markAsUpdated($issue_id);
             // need to save a history entry for this
-            History::add($issue_id, $usr_id, History::getTypeID('remote_time_added'), 'Time tracking entry submitted remotely by ' . User::getFullName($usr_id));
+            History::add($issue_id, $usr_id, History::getTypeID('remote_time_added'), ev_gettext('Time tracking entry submitted remotely by %1$s', User::getFullName($usr_id)));
             return 1;
         }
     }
@@ -526,9 +518,12 @@ class Time_Tracking
                     SUM(ttr_time_spent) as total_time
                  FROM
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "time_tracking,
+                    " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "issue,
                     " . APP_DEFAULT_DB . "." . APP_TABLE_PREFIX . "time_tracking_category
                  WHERE
+                    iss_id = ttr_iss_id AND
                     ttr_ttc_id = ttc_id AND
+                    iss_prj_id = " . Auth::getCurrentProject() . " AND
                     ttr_usr_id = " . Misc::escapeInteger($usr_id) . " AND
                     ttr_created_date BETWEEN '" . Misc::escapeString($start) . "' AND '" . Misc::escapeString($end) . "'
                  GROUP BY
@@ -552,4 +547,3 @@ class Time_Tracking
 if (APP_BENCHMARK) {
     $GLOBALS['bench']->setMarker('Included Time_Tracking Class');
 }
-?>
\ No newline at end of file
