@@ -64,7 +64,7 @@ class DateLocale {
 	array("M","T","O","T","F","L","S"));			// Swedish locale
     var $iShortDay = array(
 	array("Mon","Tue","Wed","Thu","Fri","Sat","Sun"),
-	array("Mn","Tis","Ons","Tor","Fre","Lr","Sn"));
+	array("Mån","Tis","Ons","Tor","Fre","Lör","Sön"));
     var $iShortMonth = array(
 	array("Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"),
 	array("Jan","Feb","Mar","Apr","Maj","Jun","Jul","Aug","Sep","Okt","Nov","Dec"));
