@@ -299,6 +299,12 @@ class DB_mysql extends DB_common
      */
     function simpleQuery($query)
     {
+        // increments the total number of queries
+        global $TOTAL_QUERIES;
+        $TOTAL_QUERIES++;
+        if ((defined('APP_BENCHMARK')) && (APP_BENCHMARK == true)) {
+            $GLOBALS['bench']->setMarker('BEFORE ' . $query);
+        }
         $ismanip = DB::isManip($query);
         $this->last_query = $query;
         $query = $this->modifyQuery($query);
@@ -317,6 +323,9 @@ class DB_mysql extends DB_common
             }
             $this->transaction_opcount++;
         }
+        if ((defined('APP_BENCHMARK')) && (APP_BENCHMARK == true)) {
+            $GLOBALS['bench']->setMarker('AFTER ' . $query);
+        }
         if (!$this->options['result_buffering']) {
             $result = @mysql_unbuffered_query($query, $this->connection);
         } else {
