@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,19 +22,19 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.index.php 1.11 03/09/06 00:54:04-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: index.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . '/init.php');
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 // check if templates_c is writable by the web server user
-if (!Misc::isWritableDirectory(APP_PATH . 'templates_c')) {
-    $errors = array("Directory 'templates_c' is not writable.");
+if (!Misc::isWritableDirectory(APP_TPL_COMPILE_PATH)) {
+    $errors = array("Directory '" . APP_TPL_COMPILE_PATH . "' is not writable.");
     Misc::displayRequirementErrors($errors);
     exit;
 }
@@ -44,16 +44,12 @@ $tpl->setTemplate("index.tpl.html");
 
 if (Auth::hasValidCookie(APP_COOKIE)) {
     $cookie = Auth::getCookieInfo(APP_COOKIE);
-    if ($cookie["autologin"]) {
-        if (!empty($HTTP_GET_VARS["url"])) {
-            $extra = '?url=' . $HTTP_GET_VARS["url"];
-        } else {
-            $extra = '';
-        }
-        Auth::redirect(APP_RELATIVE_URL . "select_project.php" . $extra);
+    if (!empty($_REQUEST["url"])) {
+        $extra = '?url=' . $_REQUEST["url"];
     } else {
-        $tpl->assign("email", $cookie["email"]);
+        $extra = '';
     }
+    Auth::redirect(APP_RELATIVE_URL . "select_project.php" . $extra);
 }
 
 $projects = Project::getAnonymousList();
@@ -64,4 +60,3 @@ if (empty($projects)) {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
