@@ -1,8 +1,8 @@
 <?php
-include_once("../config.inc.php");
-include_once(APP_INC_PATH . "class.custom_field.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "db_access.php");
+require_once(dirname(__FILE__) . "/../init.php");
+require_once(APP_INC_PATH . "class.custom_field.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 Auth::checkAuthentication(APP_COOKIE);
 
@@ -11,7 +11,6 @@ if (!empty($_REQUEST['iss_id'])) {
 } else {
     $fields = Custom_Field::getListByProject(Auth::getCurrentProject(), $_REQUEST['form_type']);
 }
-
 $data = array();
 foreach ($fields as $field) {
     $backend = Custom_Field::getBackend($field['fld_id']);
@@ -25,5 +24,3 @@ $tpl = new Template_API();
 $tpl->setTemplate("js/dynamic_custom_field.tpl.js");
 $tpl->assign("fields", $data);
 $tpl->displayTemplate();
-?>
-
