@@ -1,5 +1,5 @@
 <!--
-// @(#) $Id: s.global.js 1.49 03/10/20 21:24:54-00:00 jpradomaia $
+// @(#) $Id: global.js 3307 2007-04-11 23:50:22Z balsdorf $
 var today = new Date();
 var expires = new Date(today.getTime() + (56 * 86400000));
 
@@ -764,6 +764,10 @@ function replaceSpecialCharacters(e)
             thisChar = "'";
         } else if (charCode == 8230) {
             thisChar = "...";
+        } else if (charCode == 8226) {
+            thisChar = "*";
+        } else if (charCode == 8211) {
+            thisChar = "-";
         }
         newString = newString + thisChar;
     }
