@@ -2,8 +2,8 @@
 /*
  * Runonce script to set the sup_usr_id field in support_email
  */
-include_once("../../../config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
+require_once(dirname(__FILE__) . "/../../../init.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 
 $stmt = "SELECT
@@ -33,4 +33,3 @@ foreach ($res as $sup_id => $email) {
 }
 echo "complete";
 
-?>
\ No newline at end of file
