@@ -1,6 +1,6 @@
 <?php
-include_once("../../../config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
+require_once(dirname(__FILE__) . "/../../../init.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $sql = "SELECT
             pri_id,
