@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,22 +22,22 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.post.php 1.8 03/07/11 05:04:05-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.custom_field.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: post.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.custom_field.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("post.tpl.html");
 
-if (@$HTTP_POST_VARS["cat"] == "report") {
+if (@$_POST["cat"] == "report") {
     $res = Issue::addAnonymousReport();
     if ($res != -1) {
         // show direct links to the issue page, issue listing page and email listing page
@@ -46,21 +46,21 @@ if (@$HTTP_POST_VARS["cat"] == "report") {
         // need to show everything again
         $tpl->assign("error_msg", "1");
     }
-} elseif (@$HTTP_GET_VARS["post_form"] == "yes") {
+} elseif (@$_GET["post_form"] == "yes") {
     // only list those projects that are allowing anonymous reporting of new issues
     $projects = Project::getAnonymousList();
     if (empty($projects)) {
         $tpl->assign("no_projects", "1");
     } else {
-        if (!in_array($HTTP_GET_VARS["project"], array_keys($projects))) {
+        if (!in_array($_GET["project"], array_keys($projects))) {
             $tpl->assign("no_projects", "1");
         } else {
             // get list of custom fields for the selected project
-            $options = Project::getAnonymousPostOptions($HTTP_GET_VARS["project"]);
+            $options = Project::getAnonymousPostOptions($_GET["project"]);
             if (@$options["show_custom_fields"] == "yes") {
-                $tpl->assign("custom_fields", Custom_Field::getListByProject($HTTP_GET_VARS["project"], 'anonymous_form'));
+                $tpl->assign("custom_fields", Custom_Field::getListByProject($_GET["project"], 'anonymous_form'));
             }
-            $tpl->assign("project_name", Project::getName($HTTP_GET_VARS["project"]));
+            $tpl->assign("project_name", Project::getName($_GET["project"]));
         }
     }
 } else {
@@ -79,4 +79,3 @@ if (@$HTTP_POST_VARS["cat"] == "report") {
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
