@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,18 +22,28 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.preferences.php 1.9 04/01/07 15:50:18-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.prefs.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "class.date.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: preferences.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+// skip language init if we're saving language
+if (@$_POST['language']) {
+    define('SKIP_LANGUAGE_INIT', true);
+}
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.prefs.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "class.date.php");
+require_once(APP_INC_PATH . "db_access.php");
+
+// must do Language::setPreference before template is initialized
+if (@$_POST["cat"] == "update_account") {
+    $res = User::setLang(Auth::getUserID(), $_POST['language']);
+    Language::setPreference();
+}
 
 $tpl = new Template_API();
 $tpl->setTemplate("preferences.tpl.html");
@@ -42,17 +52,18 @@ Auth::checkAuthentication(APP_COOKIE);
 
 $usr_id = Auth::getUserID();
 
-if (@$HTTP_POST_VARS["cat"] == "update_account") {
+if (@$_POST["cat"] == "update_account") {
+    $tpl->assign('update_lang_result', $res);
     $res = Prefs::set($usr_id);
     $tpl->assign('update_account_result', $res);
-    User::updateSMS($usr_id, @$HTTP_POST_VARS['sms_email']);
-} elseif (@$HTTP_POST_VARS["cat"] == "update_name") {
+    User::updateSMS($usr_id, @$_POST['sms_email']);
+} elseif (@$_POST["cat"] == "update_name") {
     $res = User::updateFullName($usr_id);
     $tpl->assign('update_name_result', $res);
-} elseif (@$HTTP_POST_VARS["cat"] == "update_email") {
+} elseif (@$_POST["cat"] == "update_email") {
     $res = User::updateEmail($usr_id);
     $tpl->assign('update_email_result', $res);
-} elseif (@$HTTP_POST_VARS["cat"] == "update_password") {
+} elseif (@$_POST["cat"] == "update_password") {
     $res = User::updatePassword($usr_id);
     $tpl->assign('update_password_result', $res);
 }
@@ -66,6 +77,7 @@ if (empty($prefs)) {
 $tpl->assign("user_prefs", $prefs);
 $tpl->assign("assigned_projects", Project::getAssocList($usr_id, false, true));
 $tpl->assign("zones", Date_API::getTimezoneList());
+$tpl->assign('avail_langs', $avail_langs);
+$tpl->assign('current_locale', User::getLang(Auth::getUserID(), true));
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
