@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,31 +22,30 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.removed_emails.php 1.2 03/01/21 04:06:59-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.support.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: removed_emails.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.support.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("removed_emails.tpl.html");
 
 Auth::checkAuthentication(APP_COOKIE, NULL, true);
 
-if (@$HTTP_POST_VARS["cat"] == "restore") {
+if (@$_POST["cat"] == "restore") {
     $res = Support::restoreEmails();
     $tpl->assign("result_msg", $res);
-} elseif (@$HTTP_POST_VARS["cat"] == "remove") {
-    $res = Support::expungeEmails($HTTP_POST_VARS["item"]);
+} elseif (@$_POST["cat"] == "remove") {
+    $res = Support::expungeEmails($_POST["item"]);
     $tpl->assign("result_msg", $res);
 }
 
 $tpl->assign("list", Support::getRemovedList());
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
