@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,19 +22,19 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.rss.php 1.14 03/11/12 16:56:44-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "db_access.php");
-include_once(APP_INC_PATH . "class.setup.php");
-include_once(APP_INC_PATH . "class.filter.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.validation.php");
-include_once(APP_INC_PATH . "class.project.php");
+// @(#) $Id: rss.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "db_access.php");
+require_once(APP_INC_PATH . "class.setup.php");
+require_once(APP_INC_PATH . "class.filter.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.validation.php");
+require_once(APP_INC_PATH . "class.project.php");
 
 $setup = Setup::load();
 if (empty($setup['tool_caption'])) {
@@ -72,78 +72,78 @@ function returnError($msg)
 // Extra tweak needed for IIS/ISAPI users since the PHP_AUTH_USER/PW variables are
 // not set on that particular platform. Instead what you get is a base64 encoded
 // value of the username:password under HTTP_AUTHORIZATION
-if (!empty($HTTP_SERVER_VARS['HTTP_AUTHORIZATION'])) {
-    $pieces = explode(':', base64_decode(substr($HTTP_SERVER_VARS['HTTP_AUTHORIZATION'], 6)));
-    $HTTP_SERVER_VARS['PHP_AUTH_USER'] = $pieces[0];
-    $HTTP_SERVER_VARS['PHP_AUTH_PW'] = $pieces[1];
-} elseif ((!empty($HTTP_SERVER_VARS['ALL_HTTP'])) && (strstr($HTTP_SERVER_VARS['ALL_HTTP'], 'HTTP_AUTHORIZATION'))) {
-    preg_match('/HTTP_AUTHORIZATION:Basic (.*)/', $HTTP_SERVER_VARS['ALL_HTTP'], $matches);
+if (!empty($_SERVER['HTTP_AUTHORIZATION'])) {
+    $pieces = explode(':', base64_decode(substr($_SERVER['HTTP_AUTHORIZATION'], 6)));
+    $_SERVER['PHP_AUTH_USER'] = $pieces[0];
+    $_SERVER['PHP_AUTH_PW'] = $pieces[1];
+} elseif ((!empty($_SERVER['ALL_HTTP'])) && (strstr($_SERVER['ALL_HTTP'], 'HTTP_AUTHORIZATION'))) {
+    preg_match('/HTTP_AUTHORIZATION:Basic (.*)/', $_SERVER['ALL_HTTP'], $matches);
     if (count($matches) > 0) {
         $pieces = explode(':', base64_decode($matches[1]));
-        $HTTP_SERVER_VARS['PHP_AUTH_USER'] = $pieces[0];
-        $HTTP_SERVER_VARS['PHP_AUTH_PW'] = $pieces[1];
+        $_SERVER['PHP_AUTH_USER'] = $pieces[0];
+        $_SERVER['PHP_AUTH_PW'] = $pieces[1];
     }
 }
 
-if (!isset($HTTP_SERVER_VARS['PHP_AUTH_USER'])) {
+if (!isset($_SERVER['PHP_AUTH_USER'])) {
     authenticate();
     echo 'Error: You are required to authenticate in order to access the requested RSS feed.';
     exit;
 } else {
     // check the authentication
-    if (Validation::isWhitespace($HTTP_SERVER_VARS['PHP_AUTH_USER'])) {
+    if (Validation::isWhitespace($_SERVER['PHP_AUTH_USER'])) {
         authenticate();
         echo 'Error: Please provide your email address.';
         exit;
     }
-    if (Validation::isWhitespace($HTTP_SERVER_VARS['PHP_AUTH_PW'])) {
+    if (Validation::isWhitespace($_SERVER['PHP_AUTH_PW'])) {
         authenticate();
         echo 'Error: Please provide your password.';
         exit;
     }
     // check if user exists
-    if (!Auth::userExists($HTTP_SERVER_VARS['PHP_AUTH_USER'])) {
+    if (!Auth::userExists($_SERVER['PHP_AUTH_USER'])) {
         authenticate();
         echo 'Error: The user specified does not exist.';
         exit;
     }
     // check if the password matches
-    if (!Auth::isCorrectPassword($HTTP_SERVER_VARS['PHP_AUTH_USER'], $HTTP_SERVER_VARS['PHP_AUTH_PW'])) {
+    if (!Auth::isCorrectPassword($_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW'])) {
         authenticate();
         echo 'Error: The provided email address/password combo is not correct.';
         exit;
     }
     // check if this user did already confirm his account
-    if (Auth::isPendingUser($HTTP_SERVER_VARS['PHP_AUTH_USER'])) {
+    if (Auth::isPendingUser($_SERVER['PHP_AUTH_USER'])) {
         authenticate();
         echo 'Error: The provided user still needs to have its account confirmed.';
         exit;
     }
     // check if this user is really an active one
-    if (!Auth::isActiveUser($HTTP_SERVER_VARS['PHP_AUTH_USER'])) {
+    if (!Auth::isActiveUser($_SERVER['PHP_AUTH_USER'])) {
         authenticate();
         echo 'Error: The provided user is currently set as an inactive user.';
         exit;
     }
 
     // check if the required parameter 'custom_id' is really being passed
-    if (empty($HTTP_GET_VARS['custom_id'])) {
+    if (empty($_GET['custom_id'])) {
         returnError("Error: The required 'custom_id' parameter was not provided.");
         exit;
     }
 
-    $usr_id = User::getUserIDByEmail($HTTP_SERVER_VARS['PHP_AUTH_USER']);
+    $usr_id = User::getUserIDByEmail($_SERVER['PHP_AUTH_USER']);
     // check if the passed 'custom_id' parameter is associated with the usr_id
-    if ((!Filter::isGlobal($HTTP_GET_VARS['custom_id'])) && (!Filter::isOwner($HTTP_GET_VARS['custom_id'], $usr_id))) {
+    if ((!Filter::isGlobal($_GET['custom_id'])) && (!Filter::isOwner($_GET['custom_id'], $usr_id))) {
         returnError('Error: The provided custom filter ID is not associated with the given email address.');
         exit;
     }
 }
 
 
-$filter = Filter::getDetails($HTTP_GET_VARS["custom_id"], FALSE);
+$filter = Filter::getDetails($_GET["custom_id"], FALSE);
 
-Auth::createFakeCookie(User::getUserIDByEmail($HTTP_SERVER_VARS['PHP_AUTH_USER']), $filter['cst_prj_id']);
+Auth::createFakeCookie(User::getUserIDByEmail($_SERVER['PHP_AUTH_USER']), $filter['cst_prj_id']);
 
 $options = array(
     'users'         => $filter['cst_users'],
@@ -153,7 +153,9 @@ $options = array(
     'status'        => $filter['cst_iss_sta_id'],
     'hide_closed'   => $filter['cst_hide_closed'],
     'sort_by'       => $filter['cst_sort_by'],
-    'sort_order'    => $filter['cst_sort_order']
+    'sort_order'    => $filter['cst_sort_order'],
+    'custom_field'  => $filter['cst_custom_field'],
+    'search_type'   => $filter['cst_search_type']
 );
 $issues = Issue::getListing($filter['cst_prj_id'], $options, 0, 'ALL', TRUE);
 $issues = $issues['list'];
@@ -191,4 +193,4 @@ echo '<?xml version="1.0" encoding="'. APP_CHARSET .'"?>' . "\n";
 <?php } ?>
 
   </channel>
-</rss>
\ No newline at end of file
+</rss>
