@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,35 +22,39 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.cvs_ping.php 1.4 03/01/16 01:47:31-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.scm.php");
-include_once(APP_INC_PATH . "class.workflow.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: scm_ping.php 3307 2007-04-11 23:50:22Z balsdorf $
 
-$HTTP_GET_VARS = Misc::array_map_deep($HTTP_GET_VARS, 'base64_decode');
+// shortcut to exit out when no issue id-s are passed in request
+// as this script is always called by CVS but we handle only ones which can be
+// associated with issues.
+if (empty($_GET['issue'])) {
+    exit;
+}
 
-foreach ($HTTP_GET_VARS['issue'] as $issue_id) {
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.scm.php");
+require_once(APP_INC_PATH . "class.workflow.php");
+require_once(APP_INC_PATH . "db_access.php");
+
+foreach ($_GET['issue'] as $issue_id) {
     $files = array();
-    for ($y = 0; $y < count($HTTP_GET_VARS['files']); $y++) {
+    for ($y = 0; $y < count($_GET['files']); $y++) {
         SCM::logCheckin($issue_id, $y);
         $files[] = array(
-            'file' => $HTTP_GET_VARS['files'][$y],
-            'old_version' => $HTTP_GET_VARS['old_versions'][$y],
-            'new_version' => $HTTP_GET_VARS['new_versions'][$y],
+            'file' => $_GET['files'][$y],
+            'old_version' => $_GET['old_versions'][$y],
+            'new_version' => $_GET['new_versions'][$y],
         );
     }
 
     $prj_id = Issue::getProjectID($issue_id);
-    $module = $HTTP_GET_VARS['module'];
-    $username = $HTTP_GET_VARS['username'];
-    $commit_msg = $HTTP_GET_VARS['commit_msg'];
+    $module = $_GET['module'];
+    $username = $_GET['username'];
+    $commit_msg = $_GET['commit_msg'];
 
     Workflow::handleSCMCheckins($prj_id, $issue_id, $module, $files, $username, $commit_msg);
 }
-?>
\ No newline at end of file
