@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,17 +22,17 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.select_project.php 1.15 04/01/19 15:22:29-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.customer.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: select_project.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.customer.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("select_project.tpl.html");
@@ -42,35 +42,42 @@ if (!Auth::hasCookieSupport(APP_COOKIE)) {
     Auth::redirect(APP_RELATIVE_URL . "index.php?err=11");
 }
 
-if ((@$HTTP_GET_VARS["err"] == '') && (Auth::hasValidCookie(APP_COOKIE))) {
+if (!Auth::hasValidCookie(APP_COOKIE)) {
+    Auth::redirect(APP_RELATIVE_URL . "index.php?err=5");
+}
+
+if (@$_GET["err"] == '') {
     $cookie = Auth::getCookieInfo(APP_PROJECT_COOKIE);
     if ($cookie["remember"]) {
-        if (!empty($HTTP_GET_VARS["url"])) {
-            Auth::redirect($HTTP_GET_VARS["url"]);
+        if (!empty($_GET["url"])) {
+            Auth::redirect($_GET["url"]);
         } else {
             Auth::redirect(APP_RELATIVE_URL . "main.php");
         }
     }
-    // check if the list of active projects consists of just 
-    // one project, and redirect the user to the main page of the 
+
+    Language::setPreference();
+
+    // check if the list of active projects consists of just
+    // one project, and redirect the user to the main page of the
     // application on that case
     $assigned_projects = Project::getAssocList(Auth::getUserID());
     if (count($assigned_projects) == 1) {
         list($prj_id,) = each($assigned_projects);
         Auth::setCurrentProject($prj_id, 0);
         handleExpiredCustomer($prj_id);
-        
-        if (!empty($HTTP_GET_VARS["url"])) {
-            Auth::redirect($HTTP_GET_VARS["url"]);
+
+        if (!empty($_GET["url"])) {
+            Auth::redirect($_GET["url"]);
         } else {
             Auth::redirect(APP_RELATIVE_URL . "main.php");
         }
-    } elseif ((!empty($HTTP_GET_VARS["url"])) && (
-            (preg_match("/.*view\.php\?id=(\d*)/", $HTTP_GET_VARS["url"], $matches) > 0) ||
-            (preg_match("/switch_prj_id=(\d*)/", $HTTP_GET_VARS["url"], $matches) > 0)
+    } elseif ((!empty($_GET["url"])) && (
+            (preg_match("/.*view\.php\?id=(\d*)/", $_GET["url"], $matches) > 0) ||
+            (preg_match("/switch_prj_id=(\d*)/", $_GET["url"], $matches) > 0)
             )) {
         // check if url is directly linking to an issue, and if it is, don't prompt for project
-        if (stristr($HTTP_GET_VARS["url"], 'view.php')) {
+        if (stristr($_GET["url"], 'view.php')) {
             $prj_id = Issue::getProjectID($matches[1]);
         } else {
             $prj_id = $matches[1];
@@ -78,32 +85,32 @@ if ((@$HTTP_GET_VARS["err"] == '') && (Auth::hasValidCookie(APP_COOKIE))) {
         if (!empty($assigned_projects[$prj_id])) {
             Auth::setCurrentProject($prj_id, 0);
             handleExpiredCustomer($prj_id);
-            Auth::redirect($HTTP_GET_VARS["url"]);
+            Auth::redirect($_GET["url"]);
         }
     }
 }
 
-if (@$HTTP_GET_VARS["err"] != '') {
+if (@$_GET["err"] != '') {
     Auth::removeCookie(APP_PROJECT_COOKIE);
-    $tpl->assign("err", $HTTP_GET_VARS["err"]);
+    $tpl->assign("err", $_GET["err"]);
 }
 
-if (@$HTTP_POST_VARS["cat"] == "select") {
+if (@$_POST["cat"] == "select") {
     $usr_id = Auth::getUserID();
     $projects = Project::getAssocList($usr_id);
-    if (!in_array($HTTP_POST_VARS["project"], array_keys($projects))) {
+    if (!in_array($_POST["project"], array_keys($projects))) {
         // show error message
         $tpl->assign("err", 1);
     } else {
         // create cookie and redirect
-        if (empty($HTTP_POST_VARS["remember"])) {
-            $HTTP_POST_VARS["remember"] = 0;
+        if (empty($_POST["remember"])) {
+            $_POST["remember"] = 0;
         }
-        Auth::setCurrentProject($HTTP_POST_VARS["project"], $HTTP_POST_VARS["remember"]);
-        handleExpiredCustomer($HTTP_POST_VARS["project"]);
-        
-        if (!empty($HTTP_POST_VARS["url"])) {
-            Auth::redirect($HTTP_POST_VARS["url"]);
+        Auth::setCurrentProject($_POST["project"], $_POST["remember"]);
+        handleExpiredCustomer($_POST["project"]);
+
+        if (!empty($_POST["url"])) {
+            Auth::redirect($_POST["url"]);
         } else {
             Auth::redirect(APP_RELATIVE_URL . "main.php");
         }
@@ -115,7 +122,7 @@ $tpl->displayTemplate();
 function handleExpiredCustomer($prj_id)
 {
     GLOBAL $tpl;
-    
+
     if (Customer::hasCustomerIntegration($prj_id)) {
         // check if customer is expired
         $usr_id = Auth::getUserID();
@@ -150,5 +157,3 @@ function handleExpiredCustomer($prj_id)
         }
     }
 }
-
-?>
\ No newline at end of file
