@@ -649,4 +649,18 @@ ALTER TABLE eventum_note ADD COLUMN not_removed tinyint(1) NOT NULL DEFAULT 0;
 ALTER TABLE eventum_issue_attachment ADD COLUMN iat_status enum('internal', 'public') NOT NULL default 'public';
 ALTER TABLE eventum_issue_attachment ADD COLUMN iat_not_id int(11) unsigned DEFAULT NULL;
 
-ALTER TABLE eventum_note ADD COLUMN not_has_attachment tinyint(1) NOT NULL default 0;
\ No newline at end of file
+ALTER TABLE eventum_note ADD COLUMN not_has_attachment tinyint(1) NOT NULL default 0;
+
+# May 12th
+ALTER TABLE eventum_support_email CHANGE COLUMN sup_to sup_to text;
+ALTER TABLE eventum_support_email CHANGE COLUMN sup_cc sup_cc text;
+
+# October 2nd
+ALTER TABLE eventum_user ADD COLUMN usr_lang varchar(5);
+
+
+ALTER TABLE eventum_custom_field_option CHANGE COLUMN cfo_value cfo_value varchar(128) NOT NULL;
+
+
+# March 16th (adding missing type)
+INSERT INTO eventum_history_type SET htt_name = 'draft_routed',  htt_role = 4;
\ No newline at end of file
