@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,27 +22,26 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.spell_check.php 1.1 03/09/19 23:18:59-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: spell_check.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("spell_check.tpl.html");
 
 Auth::checkAuthentication(APP_COOKIE);
 
-if (!empty($HTTP_GET_VARS['form_name'])) {
+if (!empty($_GET['form_name'])) {
     // show temporary form
     $tpl->assign("show_temp_form", "yes");
 } else {
-    $tpl->assign("spell_check", Misc::checkSpelling($HTTP_POST_VARS['textarea']));
+    $tpl->assign("spell_check", Misc::checkSpelling($_POST['textarea']));
 }
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
