@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,15 +22,15 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.switch.php 1.3 03/01/16 01:47:32-00:00 jpm $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: switch.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $tpl = new Template_API();
 $tpl->setTemplate("switch.tpl.html");
@@ -39,9 +39,8 @@ Auth::checkAuthentication(APP_COOKIE);
 
 // get the 'remember' setting of the project cookie
 $cookie = Auth::getCookieInfo(APP_PROJECT_COOKIE);
-Auth::setCurrentProject($HTTP_POST_VARS["current_project"], $cookie["remember"]);
+Auth::setCurrentProject($_POST["current_project"], $cookie["remember"]);
 
 $tpl->assign("current_user_prefs", Prefs::get(Auth::getUserID()));
 
 $tpl->displayTemplate();
-?>
\ No newline at end of file
