@@ -1,9 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
+/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
 // +----------------------------------------------------------------------+
 // | Eventum - Issue Tracking System                                      |
 // +----------------------------------------------------------------------+
-// | Copyright (c) 2003, 2004, 2005, 2006 MySQL AB                        |
+// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
 // |                                                                      |
 // | This program is free software; you can redistribute it and/or modify |
 // | it under the terms of the GNU General Public License as published by |
@@ -22,24 +22,24 @@
 // | 59 Temple Place - Suite 330                                          |
 // | Boston, MA 02111-1307, USA.                                          |
 // +----------------------------------------------------------------------+
-// | Authors: Joo Prado Maia <jpm@mysql.com>                             |
+// | Authors: João Prado Maia <jpm@mysql.com>                             |
 // +----------------------------------------------------------------------+
 //
-// @(#) $Id: s.update.php 1.15 03/10/31 17:09:07-00:00 jpradomaia $
-//
-include_once("config.inc.php");
-include_once(APP_INC_PATH . "class.template.php");
-include_once(APP_INC_PATH . "class.auth.php");
-include_once(APP_INC_PATH . "class.issue.php");
-include_once(APP_INC_PATH . "class.category.php");
-include_once(APP_INC_PATH . "class.priority.php");
-include_once(APP_INC_PATH . "class.project.php");
-include_once(APP_INC_PATH . "class.release.php");
-include_once(APP_INC_PATH . "class.misc.php");
-include_once(APP_INC_PATH . "class.notification.php");
-include_once(APP_INC_PATH . "class.status.php");
-include_once(APP_INC_PATH . "class.group.php");
-include_once(APP_INC_PATH . "db_access.php");
+// @(#) $Id: update.php 3307 2007-04-11 23:50:22Z balsdorf $
+
+require_once(dirname(__FILE__) . "/init.php");
+require_once(APP_INC_PATH . "class.template.php");
+require_once(APP_INC_PATH . "class.auth.php");
+require_once(APP_INC_PATH . "class.issue.php");
+require_once(APP_INC_PATH . "class.category.php");
+require_once(APP_INC_PATH . "class.priority.php");
+require_once(APP_INC_PATH . "class.project.php");
+require_once(APP_INC_PATH . "class.release.php");
+require_once(APP_INC_PATH . "class.misc.php");
+require_once(APP_INC_PATH . "class.notification.php");
+require_once(APP_INC_PATH . "class.status.php");
+require_once(APP_INC_PATH . "class.group.php");
+require_once(APP_INC_PATH . "db_access.php");
 
 $prj_id = Auth::getCurrentProject();
 $usr_id = Auth::getUserID();
@@ -52,7 +52,7 @@ $tpl->setTemplate("update.tpl.html");
 
 Auth::checkAuthentication(APP_COOKIE);
 
-$issue_id = @$HTTP_POST_VARS["issue_id"] ? $HTTP_POST_VARS["issue_id"] : @$HTTP_GET_VARS["id"];
+$issue_id = @$_POST["issue_id"] ? $_POST["issue_id"] : @$_GET["id"];
 
 if (empty($issue_id)) {
     $tpl->displayTemplate();
@@ -80,10 +80,10 @@ if (($role_id == User::getRoleID('customer')) && (User::getCustomerID($usr_id) !
     $tpl->assign("auth_customer", 'denied');
 } else {
     $new_prj_id = Issue::getProjectID($issue_id);
-    if (@$HTTP_POST_VARS["cat"] == "update") {
-        $res = Issue::update($HTTP_POST_VARS["issue_id"]);
+    if (@$_POST["cat"] == "update") {
+        $res = Issue::update($_POST["issue_id"]);
         $tpl->assign("update_result", $res);
-        if (Issue::hasDuplicates($HTTP_POST_VARS["issue_id"])) {
+        if (Issue::hasDuplicates($_POST["issue_id"])) {
             $tpl->assign("has_duplicates", "yes");
         }
     }
@@ -121,7 +121,8 @@ if (($role_id == User::getRoleID('customer')) && (User::getCustomerID($usr_id) !
         "assoc_issues" => array_map("htmlspecialchars", Issue::getAssocList()),
         "one_week_ts"  => time() + (7 * DAY),
         "allow_unassigned_issues"   =>  @$setup["allow_unassigned_issues"],
-        "groups"       => Group::getAssocList($prj_id)
+        "groups"       => Group::getAssocList($prj_id),
+        'current_year' =>   date('Y'),
     ));
 
     $cookie = Auth::getCookieInfo(APP_PROJECT_COOKIE);
@@ -133,4 +134,3 @@ if (($role_id == User::getRoleID('customer')) && (User::getCustomerID($usr_id) !
     }
 }
 $tpl->displayTemplate();
-?>
\ No newline at end of file
